<?php
/**
 * Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 *
 * @package Wembley
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses wembley_header_style()
 * @uses wembley_admin_header_style()
 * @uses wembley_admin_header_image()
 */
function wembley_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'wembley_custom_header_args', array(
		'default-image'          => get_template_directory_uri() . '/images/header.jpg',
		'default-text-color'     => '000000',
		'width'                  => 1900,
		'height'                 => 400,
		'flex-height'            => true,
		'uploads'                => true,
		'wp-head-callback'       => 'wembley_header_style',
		'admin-head-callback'    => 'wembley_admin_header_style',
		'admin-preview-callback' => 'wembley_admin_header_image',
	) ) );
}
add_action( 'after_setup_theme', 'wembley_custom_header_setup' );

if ( ! function_exists( 'wembley_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @see wembley_custom_header_setup().
 */
function wembley_header_style() {
	$header_text_color = get_header_textcolor();

	// If no custom options for text are set, let's bail
	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == $header_text_color ) {
		return;
	}

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == $header_text_color ) :
	?>
		.site-title,
		.site-description {
			position: absolute;
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		.site-title a, h2.site-description, 
		.jumbotron .jumbotron-holder h1.site-description, .jumbotron .jumbotron-holder {
			color: #<?php echo esc_attr( $header_text_color ); ?>;
		}
		.jumbotron .jumbotron-holder h1:before {background: #<?php echo esc_attr( $header_text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // wembley_header_style

if ( ! function_exists( 'wembley_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @see wembley_custom_header_setup().
 */
function wembley_admin_header_style() {
?>
	<style type="text/css">
		.appearance_page_custom-header #headimg {
			border: none;
		}
		#headimg h1,
		#desc {
		}
		#headimg h1 {
		}
		#headimg h1 a {
		}
		#desc {
		}
		#headimg img {
		}
	</style>
<?php
}
endif; // wembley_admin_header_style

if ( ! function_exists( 'wembley_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * @see wembley_custom_header_setup().
 */
function wembley_admin_header_image() {
	$style = sprintf( ' style="color:#%s;"', get_header_textcolor() );
?>
	<div id="headimg">
		<h1 class="displaying-header-text"><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div class="displaying-header-text" id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php if ( get_header_image() ) : ?>
		<img src="<?php header_image(); ?>" alt="">
		<?php endif; ?>
	</div>
<?php
}
endif; // wembley_admin_header_image